==> plFileHandler-0.1.zip: plFileHandler/action.default.php <==
<?php
if(!isset($gCms))	exit;

$returninput = isset($params['returnInput'])?$params['returnInput']:false;
if(!$returninput || $returninput == '')	return false;

$doinit = (isset($params['noinit']) && $params['noinit'])?false:true;

$width = (int)	(isset($params['width'])?$params['width']:$this->GetPreference('default_popup_width', 480));
$height = (int)	(isset($params['height'])?$params['height']:$this->GetPreference('default_popup_height', 400));
if( !($width>100) ) $width = 480;
if( !($height>100) ) $height = 480;

$url = '';

$method = (isset($params['method']) && in_array($params['method'], array('upload','select')))?$params['method']:'both';

foreach(array('allowedext','mode','resize','crop','curdir','startdir','multiple') as $key){
	if(isset($params[$key]))	$url .= ($url==''?'':'&').$key.'='.urlencode($params[$key]);
}

if($doinit)	echo '<script type="text/javascript">
'.$this->getFileContent('plFileHandler.js').'
plFileHandler.init('.$width.','.$height.');
</script>';

$baseurl = $gCms->config['root_url'].'/modules/plFileHandler/';

$currentvalue = (isset($params['current'])?$params['current']:false);

$select_js = "plFileHandler.load('".$baseurl."bg_select.php".($url==''?'':'?'.$url)."', '".$returninput."'); return false;";
$upload_js = "plFileHandler.load('".$baseurl."bg_upload.php".($url==''?'':'?'.$url)."', '".$returninput."'); return false;";
$remove_js = "plFileHandler.remove('".$returninput."');";
$this->smarty->assign('method', $method);
if($method == 'upload'){
	$this->smarty->assign('select_js', false);
	$this->smarty->assign('select_link', false);
}else{
	$this->smarty->assign('select_js', $select_js);
	$this->smarty->assign('select_link', '<a style="cursor: pointer;" onclick="'.$select_js.'">'.$this->Lang('select').'</a>');
}
if($method == 'select'){
	$this->smarty->assign('upload_js', false);
	$this->smarty->assign('upload_link', false);
}else{		
	$this->smarty->assign('upload_js', $upload_js);
	$this->smarty->assign('upload_link', '<a style="cursor: pointer;" onclick="'.$upload_js.'">'.$this->Lang('upload').'</a>');
}
$this->smarty->assign('remove_js', $remove_js);
$this->smarty->assign('remove_link', '<a style="cursor: pointer;" onclick="'.$remove_js.'">'.$this->Lang('remove').'</a>');

if($currentvalue){
	$extension = strtolower(substr(strrchr($currentvalue, "."), 1));
	if(in_array($extension, array('jpeg','jpg','gif','png'))){
		$parts = explode('/',$currentvalue);
		$parts[count($parts)-1] = 'thumb_'.$parts[count($parts)-1];
		$thumbpath = '/'.implode('/',$parts);
		if(file_exists($gCms->config['uploads_path'].$thumbpath)){
			$pic = '<img src="'.$gCms->config['uploads_url'].$thumbpath.'" alt=""/>';
		}else{
			$pic = '<img src="'.$this->GetFileIcon($currentvalue).'" alt=""/>';
		}
	}else{
		$pic = '<img src="'.$this->GetFileIcon($currentvalue).'" alt=""/>';
	}
}else{
	$pic = '<img src="" alt=""/>';
}

$this->smarty->assign('current_pic', $pic);
$this->smarty->assign('current_name', $currentvalue?basename($currentvalue):false);
$this->smarty->assign('current_url', $gCms->config['uploads_url'].'/'.$currentvalue);
$this->smarty->assign('currentdiv_id', $returninput.'_currentfile');

$output = $this->ProcessTemplateFromDatabase('selector');

==> plFileHandler-0.2.zip: plFileHandler/action.default.php <==
<?php
if(!isset($gCms))	exit;

$returninput = isset($params['returnInput'])?$params['returnInput']:false;
if(!$returninput || $returninput == '')	return false;

$doinit = (isset($params['noinit']) && $params['noinit'])?false:true;

$width = (int)	(isset($params['width'])?$params['width']:$this->GetPreference('default_popup_width', 480));
$height = (int)	(isset($params['height'])?$params['height']:$this->GetPreference('default_popup_height', 400));
if( !($width>100) ) $width = 480;
if( !($height>100) ) $height = 480;

$url = '';

$method = (isset($params['method']) && in_array($params['method'], array('upload','select')))?$params['method']:'both';

foreach(array('allowedext','mode','resize','crop','curdir','startdir','multiple') as $key){
	if(isset($params[$key]))	$url .= ($url==''?'':'&').$key.'='.urlencode($params[$key]);
}

if($doinit)	echo '<script type="text/javascript">
'.$this->getFileContent('plFileHandler.js').'
plFileHandler.init('.$width.','.$height.');
</script>';

$baseurl = $gCms->config['root_url'].'/modules/plFileHandler/';

$currentvalue = (isset($params['current'])?$params['current']:false);

$select_js = "plFileHandler.load('".$baseurl."bg_select.php".($url==''?'':'?'.$url)."', '".$returninput."'); return false;";
$upload_js = "plFileHandler.load('".$baseurl."bg_upload.php".($url==''?'':'?'.$url)."', '".$returninput."'); return false;";
$remove_js = "plFileHandler.remove('".$returninput."');";
$this->smarty->assign('method', $method);
if($method == 'upload'){
	$this->smarty->assign('select_js', false);
	$this->smarty->assign('select_link', false);
}else{
	$this->smarty->assign('select_js', $select_js);
	$this->smarty->assign('select_link', '<a style="cursor: pointer;" onclick="'.$select_js.'">'.$this->Lang('select').'</a>');
}
if($method == 'select'){
	$this->smarty->assign('upload_js', false);
	$this->smarty->assign('upload_link', false);
}else{		
	$this->smarty->assign('upload_js', $upload_js);
	$this->smarty->assign('upload_link', '<a style="cursor: pointer;" onclick="'.$upload_js.'">'.$this->Lang('upload').'</a>');
}
$this->smarty->assign('remove_js', $remove_js);
$this->smarty->assign('remove_link', '<a style="cursor: pointer;" onclick="'.$remove_js.'">'.$this->Lang('remove').'</a>');

if($currentvalue){
	$extension = strtolower(substr(strrchr($currentvalue, "."), 1));
	if(in_array($extension, array('jpeg','jpg','gif','png'))){
		$parts = explode('/',$currentvalue);
		$parts[count($parts)-1] = 'thumb_'.$parts[count($parts)-1];
		$thumburl = implode('/',$parts);
		if(file_exists($this->get_path_from_url($thumburl))){
			$pic = '<img src="'.$thumburl.'" alt=""/>';
		}else{
			$pic = '<img src="'.$this->GetFileIcon($currentvalue).'" alt=""/>';
		}
	}else{
		$pic = '<img src="'.$this->GetFileIcon($currentvalue).'" alt=""/>';
	}
}else{
	$pic = '<img src="" alt=""/>';
}

$this->smarty->assign('current_pic', $pic);
$this->smarty->assign('current_name', $currentvalue?basename($currentvalue):false);
$this->smarty->assign('current_url', $gCms->config['uploads_url'].'/'.$currentvalue);
$this->smarty->assign('currentdiv_id', $returninput.'_currentfile');

$output = $this->ProcessTemplateFromDatabase('selector');
